@@ -1,7 +1,7 @@
 from enum import Enum
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple
 
-from pydantic import Field, constr, validator, conlist
+from pydantic import Field, conlist, constr, validator
 
 from ..util import provenance_stamp
 from .basemodels import ProtoModel
@@ -257,7 +257,15 @@ class TorsionDriveResult(TorsionDriveInput):
 
 
 def Optimization(*args, **kwargs):
+    """QC Optimization Results Schema.
+
+    .. deprecated:: 0.12
+       Use :py:func:`qcelemental.models.OptimizationResult` instead.
+
+    """
     from warnings import warn
 
-    warn("Optimization has been renamed to OptimizationResult and will be removed in v0.13.0", DeprecationWarning)
+    warn(
+        "Optimization has been renamed to OptimizationResult and will be removed as soon as v0.13.0", DeprecationWarning
+    )
     return OptimizationResult(*args, **kwargs)
