@@ -18,38 +18,38 @@ def to_string(
     prec: int = 12,
     return_data: bool = False,
 ) -> Union[str, Tuple[str, Dict]]:
-    """Format a string representation of QM molecule.
+    r"""Format a string representation of QM molecule.
 
     Parameters
     ----------
-    molrec : Dict
+    molrec
         Psi4 json Molecule spec.
-    dtype : str, {'xyz', 'cfour', 'nwchem', 'molpro', 'orca', 'turbomole',
-                  'qchem'}
+    dtype
+        {"xyz", "cfour", "nwchem", "molpro", "orca", "turbomole", "qchem"}
         Overall string format. Note that it's possible to request variations
         that don't fit the dtype spec so may not be re-readable (e.g., ghost
         and mass in nucleus label with ``'xyz'``).
         'cfour' forces nucleus label, ignoring atom_format, ghost_format
-    units : str, optional
+    units
         Units in which to write string. Usually ``Angstrom`` or ``Bohr``
         but may be any length unit.  There is not an option to write in
         intrinsic/input units. For ``dtype='xyz', units='Bohr'`` where the
         format doesn't have a slot to specify units, "au" is added so that
         readable as ``dtype='xyz+'``.
-    atom_format : str, optional
+    atom_format
         General format is ``'{elem}'``. A format string that may contain fields
         'elea' (-1 will be ''), 'elez', 'elem', 'mass', 'elbl' in any
         arrangement. For example, if a format naturally uses element symbol
         and you want atomic number instead with mass info, too, pass
         ``'{elez}@{mass}'``. See `ghost_format` for handling field 'real'.
-    ghost_format : str, optional
+    ghost_format
         General format is ``'@{elem}'``. Like `atom_format`, but this formatter
         is used when `real=False`. To suppress ghost atoms, use `ghost_format=''`.
-    width : int, optional
+    width
         Field width for formatting coordinate float.
-    prec : int, optional
+    prec
         Number of decimal places for formatting coordinate float.
-    return_data : bool, optional
+    return_data
         Whether to return dictionary with additional info from the molrec that's
         not expressible in the string but may be of interest to the QC program.
         Note that field names are in QCSchema, not molrec, language.
@@ -59,10 +59,11 @@ def to_string(
     str
         String representation of the molecule.
     str, dict
-        When ``return_data=True`, return additionally a dictionary
-            keywords: key, value pairs for processing molecule info into options
-            fields: aspects of ``qcelemental.models.Molecule`` expressed into
-                    string _or_ keywords.
+        When ``return_data=True``, return additionally a dictionary
+
+          * keywords: key, value pairs for processing molecule info into options
+          * fields: aspects of ``qcelemental.models.Molecule`` expressed into string *or* keywords.
+            Model fields *not* listed are lost in QCSchema -> QC DSL translation.
 
     """
 
@@ -171,7 +172,7 @@ def to_string(
         smol = [tagline]
         smol.extend(atoms)
 
-        data.fields.extend(["molecular_charge", "molecular_multiplicity"])
+        data.fields.extend(["molecular_charge", "molecular_multiplicity", "real"])
         data.keywords = {
             "charge": int(molrec["molecular_charge"]),
             "multiplicity": molrec["molecular_multiplicity"],
@@ -220,8 +221,8 @@ def to_string(
 
     elif dtype == "nwchem":
 
-        atom_format = "{elem}"
-        ghost_format = "GH"
+        atom_format = "{elem}{elbl}"
+        ghost_format = "bq{elem}{elbl}"
         # TODO handle which units valid
         umap = {"bohr": "bohr", "angstrom": "angstroms", "nm": "nanometers", "pm": "picometers"}
 
@@ -239,11 +240,12 @@ def to_string(
         smol.append(symm_line)
         smol.append(last_line)
 
-        data.fields.extend(["molecular_charge", "molecular_multiplicity"])
+        data.fields.extend(["molecular_charge", "molecular_multiplicity", "real"])
         data.keywords = {"charge": int(molrec["molecular_charge"])}
         if molrec["molecular_multiplicity"] != 1:
             data.keywords["scf__nopen"] = molrec["molecular_multiplicity"] - 1
             data.keywords["dft__mult"] = molrec["molecular_multiplicity"]
+            data.keywords["mcscf__multiplicity"] = molrec["molecular_multiplicity"]
 
     elif dtype == "madness":
 
@@ -269,23 +271,31 @@ def to_string(
             data.keywords["spin_restricted"] = "false"
 
     elif dtype == "gamess":
+        # * GAMESS can't detect or run in symmetry w/o explicit notation
+        # * symm detection is out-of-scope for qcel -- hence the explicit C1 default
+        # * symm provisionally hackable by passing both point group and naxis (if needed)
+        #   through ``fix_symmetry``. newline encoded here if needed.
+        # * coord=prinaxis, as set up here, can't handle ghost atoms
 
         atom_format = " {elem}{elbl} {elez}"
-        ghost_format = " {BQ} -{elez}"
+        ghost_format = " {elem} -{elez}"
         umap = {"bohr": "bohr", "angstrom": "angs"}
 
         atoms = _atoms_formatter(molrec, geom, atom_format, ghost_format, width, prec, 2)
 
         first_line = """ $data"""
-        second_line = f""" {tagline}"""
-        third_line = """ C1"""
+        second_line = f""" {tagline}"""  # card -1-
+        fix_symm = molrec.get("fix_symmetry", "C1").strip()
+        symm_line = f" {fix_symm}"  # card -2-
+        if fix_symm.upper() != "C1":
+            symm_line += "\n"  # blank card replaces -3- & -4-
         last_line = """ $end"""
 
-        smol = [first_line, second_line, third_line]
-        smol.extend(atoms)
+        smol = [first_line, second_line, symm_line]
+        smol.extend(atoms)  # card -5C-
         smol.append(last_line)
 
-        data.fields.extend(["molecular_charge", "molecular_multiplicity"])
+        data.fields.extend(["molecular_charge", "molecular_multiplicity", "real"])
         data.keywords = {
             "contrl__icharg": int(molrec["molecular_charge"]),
             "contrl__mult": molrec["molecular_multiplicity"],
@@ -385,7 +395,7 @@ def to_string(
 
         atom_format = "{elem}"
         ghost_format = "@{elem}"
-        umap = {"bohr": True, "angstrom": False}
+        umap = {"bohr": "True", "angstrom": "False"}
 
         atoms = _atoms_formatter(molrec, geom, atom_format, ghost_format, width, prec, 2)
 
